@@ -1,21 +1,34 @@
+/*
+Portions Copyright 2019-2021 ZomboDB, LLC.
+Portions Copyright 2021-2022 Technology Concepts & Design, Inc. <support@tcdi.com>
+
+All rights reserved.
+
+Use of this source code is governed by the MIT license that can be found in the LICENSE file.
+*/
 use cargo_metadata::Metadata;
 use cargo_toml::Manifest;
 use eyre::eyre;
-use std::path::PathBuf;
 use pgx_utils::SUPPORTED_MAJOR_VERSIONS;
+use std::path::PathBuf;
 
 #[tracing::instrument(skip_all)]
-pub(crate) fn manifest_path(metadata: &Metadata, package_name: Option<&String>) -> eyre::Result<PathBuf> {
+pub(crate) fn manifest_path(
+    metadata: &Metadata,
+    package_name: Option<&String>,
+) -> eyre::Result<PathBuf> {
     let manifest_path = if let Some(package_name) = package_name {
-        let found = metadata.packages.iter()
+        let found = metadata
+            .packages
+            .iter()
             .find(|v| v.name == *package_name)
             .ok_or_else(|| eyre!("Could not find package `{}`", package_name))?;
         tracing::debug!(manifest_path = %found.manifest_path, "Found workspace package");
         found.manifest_path.clone().into_std_path_buf()
     } else {
-        let root = metadata
-            .root_package()
-            .ok_or(eyre!("`pgx` requires a root package in a workspace when `--package` is not specified."))?;
+        let root = metadata.root_package().ok_or(eyre!(
+            "`pgx` requires a root package in a workspace when `--package` is not specified."
+        ))?;
         tracing::debug!(manifest_path = %root.manifest_path, "Found root package");
         root.manifest_path.clone().into_std_path_buf()
     };
